var FOWlib =
(function($){
/**
 * create DOM-manipulation object
 * @see http://stackoverflow.com/questions/779880/in-javascript-can-you-extend-the-dom/780701#780701
 */
var myDOM = function(elems){
		return new MyDOMConstruct(elems);
	},
	/**
	 * from reference, modified from jQuery
	 */
	MyDOMConstruct = function(selector, context) {
		this.length = 0;
		
		//null, undefined, etc
		if(! selector){
			return this;
		}

		//DOMelement
		if( selector.nodeType ){
			this.context = this[0] = selector;
			this.length = 1;
			return this;
		}
		
		//list of DOMelement?  is actually an HTMLCollection, not an array...wow
		if( LIB.tools.isHtmlCollection( selector ) ){
			for(var i = 0; i < selector.length; i++){
				this[i] = selector[i];
			}
			this.length = selector.length
			this.context = this[0];	//??
			return this;
		}
		
		//string -- assumes id?
		if( typeof selector === "string" ){
			context = context instanceof MyDOMConstruct ? context[0] : context;
			doc = (context ? context.ownerDocument || context : document);

			this[0] = doc.getElementById(selector);
			this.length = 1;
			this.context = context || this[0];
		}

		
		//this.collection = elems[1] ? Array.prototype.slice.call(elems) : [elems];
		return this;
	};

/**
 * add DOM-related functions
 * @see http://stackoverflow.com/questions/779880/in-javascript-can-you-extend-the-dom/780701#780701
 */
myDOM.fn = MyDOMConstruct.prototype = {
	forEach : function(fn) {
		for (var i = 0, l = this.length; i < l; i++) {
			fn( this[i], i );
		}
		return this;
	}//---	myDom.fn.forEach
	,
	addStyles : function(styles) {
		for (var i = 0, l = this.length; i < l; i++) {
			for (var prop in styles) {
				this[i].style[prop] = styles[prop];
			}
		}
		return this;
	}//---	myDOM.fn.addStyles
	,
	/**
	 * Internal data accessor
	 */
	data : function(key, val){
		//start the storage if we haven't already
		if(this._data === undefined){
			this._data = {};
		}
		//just returning the value
		if( val === undefined ){
			return this._data[key];
		}
		
		this._data[key] = val;
		return this;
	}//---	myDOM.fn.data
	,
	/**
	 * Toggle show/hide
	 */
	toggle : function(){
		//remember previous state
		if(this.data('toggle') == undefined){
			this.data('toggle', { s0: false, s1: true, sn: 0});
			if(this[0].style === undefined || this[0].style.display === undefined){
				this.data('toggle').s0 = '';
			}
			else {
				this.data('toggle').s0 = this[0].style.display;
			}
			//set the opposite state based on starting state
			if(this.data('toggle').s0 == 'none'){
				this.data('toggle').s1 = '';
			}
			else {
				this.data('toggle').s1 = 'none';
			}
		}
		this.data('toggle').sn++;
		
		this[0].style.display = this.data('toggle')['s' + (this.data('toggle').sn % 2)];
		
		return this;
	}//---	myDOM.fn.toggle
	,
	/**
	 * Get/Set an attribute?
	 */
	attr : function(property, value){
		if(value == undefined){
			return this[0][property];
		}
		///TODO: sanitize this
		this[0][property] = value;
		return this;
	}//---	myDOM.fn.attr
	,
	/**
	 * Inject another dom element into this object
	 */
	addElement : function(dom){
		this[ this.length ] = dom;
		this.length++;
		return this;
	}//---	myDOM.fn.addElement
	,
	/**
	 * Check for native functionality, if not duplicate it
	 * adapted from @see reference
	 * @see http://stackoverflow.com/questions/1933602/how-to-getelementbyclass-instead-of-getelementbyid-with-javscript/1933623#1933623
	 * @usage getElementsByProperty(document,'class')
	 */
	getElementsByProperty:  function (property,selector) {
		var results = new myDOM();	// []
		for(var i = 0, node = this[i]; i < this.length; i++){
		
			switch(property){
				case 'id': return myDOM(selector);
					break;
				case 'class':
					property = 'className';	//correct for javascript
					if (node.getElementsByClassName) { // use native implementation if available
						var foundElements = node.getElementsByClassName(selector);
						for(var i = 0, iStop = foundElements.length; i < iStop; i++){
							results.addElement( foundElements[i] );		////results.push( myDOM( foundElements[i] ) );
						}
						continue;
					}
					//otherwise, use the generic property way
				default:
					//why would node be nothing?
					if ( node == null || node === undefined )	node = document;
					
					var	els = node.getElementsByTagName("*")
						, pattern = new RegExp("(^|\\s)"+selector+"(\\s|$)")
						;

					for(var i = 0, iStop = els.length; i < iStop; i++){	//use for-loop instead of foreach to avoid IE error for undefined els[i]?
						if ( pattern.test(els[i][property]) ) {
							results.addElement( els[i] );			////foundElements.push( myDOM(els[i]) );
						}
					}
					break;
			}//-- switch
		
		}//-- collection loop
		
		//empty result check
		if( results.length == 0 ) return new myDOM();
		
		return results;
	}//---	lib.fn.getElementsByProperty
	,
	/**
	 * Inject a DOM-element in the beginning of its contents
	 */
	prepend : function(toInsert){
		var target = this[0];
		target.insertBefore(toInsert, target.firstChild);
		return this;
	}//---	lib.fn.prepend
	,
	/**
	 * Inject a DOM-element after the specified target
	 * @see http://www.netlobo.com/javascript-insertafter.html
	 */
	insertAfter : function(newNode){
		var referenceNode = this[0];
		referenceNode.parentNode.insertBefore( newNode, referenceNode.nextSibling );
		return this;
	}//---	lib.fn.insertAfter
	,
	/**
	 * Remove the DOM-element
	 */
	remove : function(){
		if(this.length){
			for(var i = 0; i < this.length; i++){
				this[i].parentNode.removeChild(this[i]);
				delete this[i];
			}
		}
		this.length = 0;
		return this;
	}//---	lib.fn.remove
	,
	/**
	 * Get the parent (of the first internal item!)
	 */
	parent : function(){
		return this[0].parentNode;
	}
	,
	/**
	 * Fire an ajax request with callbacks, load result (on success) to self
	 */
	load : function(url, onSuccess, onFailure, type, async){
		var self = this;
		var macroOnSuccess = function(data){
			//put content in target
			self.forEach(function(o){
				o.innerHTML = data;
			});
			
			//now callback
			if(onSuccess) onSuccess(data);
		};
		
		LIB.tools.ajax.request(type, url, macroOnSuccess, onFailure, async);
	}//---	LIB.tools.ajax.load
	,
	
	clone : function(){
		alert('clone() -- TODO');
	}//---	lib.fn.clone

};	//myDOM.fn

/**
 * create static function library; attach these to DOM-manipulation thing later
 */
var LIB = {
	/**
	 * Generic tool methods
	 */
	tools : {
		ajax : {
			request : function(type, url, onSuccess, onFailure, async){
				var xmlhttp;
				
				// code for IE7+, Firefox, Chrome, Opera, Safari
				if (window.XMLHttpRequest) {
					xmlhttp=new XMLHttpRequest();
				}
				// code for IE6, IE5
				else {
					xmlhttp=new ActiveXObject("Microsoft.XMLHTTP");
				}
				xmlhttp.onreadystatechange = function() {
					if (xmlhttp.readyState==4 && xmlhttp.status==200) {
						if( onSuccess ){
							onSuccess(xmlhttp.responseText);
							return true;
						}
					}
					else {
						if( onFailure ){
							onFailure(xmlhttp.readyState, xmlhttp.status);
							return false;
						}
					}
				};//-- xmlhttp.onreadystatechange
				
				//now actually fire the event
				xmlhttp.open(
					(type === undefined ? 'get' : type).toUpperCase()
					, url
					, (async === undefined ? true : async)
					);
				xmlhttp.send();
			}//---	LIB.tools.ajax.request
			,
			/**
			 * Shorthand for request('GET')
			 */
			get : function(url, onSuccess, onFailure, async){
				this.request('GET', url, onSuccess, onFailure, async);
			}//---	LIB.tools.ajax.get
		}///----	LIB.tools.ajax
		,
		/**
		 * As explained in see
		 * @see http://perfectionkills.com/instanceof-considered-harmful-or-how-to-write-a-robust-isarray/
		 */
		isArray: function(o) {
			return Object.prototype.toString.call(o) === '[object Array]';
			}
		,
		/**
		 * Like isArray
		 */
		isHtmlCollection: function(o) {
			return Object.prototype.toString.call(o) === '[object HTMLCollection]';
			}
		,
		/**
		 * Check if given thing is an object
		 */
		isObject: function(o) { return (typeof o === 'object'); }
		,
		/**
		 * Safe logging wrapper
		 */
		log: function() { if( window.console && window.console.log ){ window.console.log(Array.prototype.slice.call(arguments)); } }
		,
		/**
		 * Check for native functionality, if not duplicate it
		 * @see http://stackoverflow.com/questions/1933602/how-to-getelementbyclass-instead-of-getelementbyid-with-javscript/1933623#1933623
		 * @usage getElementsByClassName(document, className)
		 */
		getElementsByClassName:  function (node,classname) {
			if (node.getElementsByClassName) { // use native implementation if available
				return node.getElementsByClassName(classname);
			} else {
				return (function getElementsByClass(searchClass,node) {
					if ( node == null || node === undefined )	node = document;
					var	  classElements = []
						, els = node.getElementsByTagName("*")
						, elsLen = els.length
						, pattern = new RegExp("(^|\\s)"+searchClass+"(\\s|$)")
						, i
						;

					for (i = 0; i < elsLen; i++) {
						//why would els[i] be null in IE?
						if ( els[i] && pattern.test(els[i].className) ) {
							classElements.push( els[i] );
						}
					}
					return classElements;
				})(classname, node);
			}
		}//---	lib.tools.getElementsByClassName
		,
		/**
		 * Check for native functionality, if not duplicate it
		 * adapted from @see reference
		 * @see http://stackoverflow.com/questions/1933602/how-to-getelementbyclass-instead-of-getelementbyid-with-javscript/1933623#1933623
		 * @usage getElementsByProperty(document,'class')
		 */
		getElementsByProperty:  function (node,property,selector) {
			switch(property){
				case 'id': return node.getElementById(selector);
					break;
				case 'class':
					property = 'className';	//correct for javascript
					if (node.getElementsByClassName) { // use native implementation if available
						return node.getElementsByClassName(selector);
					}
					//otherwise, use the generic property way
				default:
					//why would node be nothing?
					if ( node == null || node === undefined )	node = document;
					
					var	  foundElements = []
						, els = node.getElementsByTagName("*")
						, pattern = new RegExp("(^|\\s)"+selector+"(\\s|$)")
						;

					for(var i = 0, iStop = els.length; i < iStop; i++){	//use for-loop instead of foreach to avoid IE error for undefined els[i]?
						if ( pattern.test(els[i][property]) ) {
							foundElements.push( els[i] );
						}
					}
					return foundElements;
					break;
			}
		}//---	lib.tools.getElementsByProperty
		,
		/**
		 * Inject a DOM-element in the beginning of its contents
		 */
		prepend : function(target, toInsert){
			target.insertBefore(toInsert, target.firstChild);
		}//---	lib.tools.prepend
		,
		/**
		 * Inject a DOM-element after the specified target
		 * @see http://www.netlobo.com/javascript-insertafter.html
		 */
		insertAfter : function(referenceNode, newNode){
			referenceNode.parentNode.insertBefore( newNode, referenceNode.nextSibling );
		}//---	lib.tools.insertAfter

	}///----	lib.tools
	,
	/**
	 * Form-specific methods and properties
	 */
	form : {
		/**
		 * Return an array of form inputs of all kinds
		 */
		getInputs:  function(formId, inputType){
			var Form = document.getElementById(formId)
				, Inputs
				;
				
			//get other input types (for text validation)
			Inputs = Form.getElementsByTagName('input');
			Inputs.concat( Form.getElementsByTagName('textarea') );
			
			
			//get other input types (for required validation, etc)
			Inputs.concat( Form.getElementsByTagName('select') );
			Inputs.concat( Form.getElementsByTagName('checkbox') );
			
			return Inputs;
		}//---	lib.form.getInputs
		,
		/**
		 * Helper to make error DOMelement
		 */
		makeErrorMessage : function(msg, tag, id){
			if( tag === undefined ) tag = 'em';
			var errorDOM = document.createElement(tag);
			
			errorDOM.className = 'error-msg';
			if(id && id !== undefined){
				errorDOM.id = id;
			}
			errorDOM.innerHTML = msg;
			return errorDOM;
		}//---	lib.form.makeErrorMessage
		,
		/**
		 * on submit callback
		 */
		validate:  function(formId){
			var	Form
				, Inputs
				, hasError = false
				, errorDOM = LIB.form.makeErrorMessage('Required!')
				;
			
			//if for some reason we're not given the formId, just get the first form on the page
			if( formId == null || formId === undefined ){
				Form = document.getElementsByTagName('form');
				Form = myDOM(Form[0]);
			}
			else {
				Form = myDOM(formId);
			}
			
			//clear old messages
			var errorMsgs = Form.getElementsByProperty('class', 'error-msg');
			errorMsgs.remove();
			
			//clear error classes
			errorMsgs = Form.getElementsByProperty('class', 'has-error');
			errorMsgs.forEach(function(o){
				o.className = o.className.replace('has-error', '');
			});
			
			//check for required items
			Inputs = Form.getElementsByProperty('class', 'required');
			Inputs.forEach(function(o){
				var $o = myDOM(o);
				if($o.attr('value') == ''){
					hasError = true;
					$o.parent().className += ' has-error';
					$o.parent().appendChild(errorDOM.cloneNode(true));
				}
			});
			
			//add a warning message
			if(hasError){
				Form.prepend(LIB.form.makeErrorMessage('Please correct the errors below', 'div'));
			}
			
			return !hasError;
		}//---	lib.form.validate
	}///----	lib.form
	,
	/**
	 * Shipping specific methods and properties
	 */
	shipping : {
		/**
		 * fuel surcharge calculation - part of equation
		 */
		fuel_surcharge: 0.2
		,
		/**
		 * Populate the state dropdown from our factor list
		 */
		initStates : function(){
			setTimeout(function(){
				var target = document.getElementById('state')
					, option
					;
					
				///TODO need to sort the properties...
				
				//loop through states given in factors
				for(var state in LIB.shipping.factors){
					option = document.createElement('option');
					option.value = state;
					option.innerHTML = state;
					
					target.appendChild(option);
				}
			},1000);
			
		}//---	lib.shipping.initStates
		,
		/**
		 * Listing of shipping calculation factors by state and zipcode
		 * used in equation (weight-factor) * (1 + surcharge) + 25
		 * 
		 * Given as -- state: [ list of factor objects ]
		 * where each factor object is:
		 *		pre:	0 or -1 for any zipcode, unless given as array of specific code prefixes, where given codes can be a single zip or a min-max range
		 *		fwA:	weight-factor for <= 200 lbs
		 *		fB:		part of weight-factor (fB * W) for 201 - 999 lbs
		 *		fC:		part of weight-factor (fC * W) for 1000+ lbs
		 */
		factors : {
			  "AL": [ {pre: 0, fwA: 131.00, fB: 0.69, fC: 0.64} ]
			, "AR": [ {pre: 0, fwA: 157.00, fB: 0.82, fC: 0.78} ]
			, "AZ": [ {pre: 0, fwA: 216.00, fB: 1.13, fC: 1.07} ]
			, "CA": [ {pre: [ {min:936, max:961} ], fwA: 235.00, fB: 1.23, fC: 1.16}, {pre: -1, fwA: 226.00, fB: 1.18, fC: 1.13} ]
			, "CO": [ {pre: 0, fwA: 207.00, fB: 1.08, fC: 1.03} ]
			, "CT": [ {pre: 0, fwA: 138.00, fB: 0.73, fC: 0.68} ]
			, "DC": [ {pre: 0, fwA: 113.00, fB: 0.59, fC: 0.56} ]
			, "DE": [ {pre: 0, fwA: 115.00, fB: 0.6, fC: 0.56} ]
			, "FL": [ {pre: [ {min:320, max:322}, {min:335, max:337}, 344, 346, 347 ], fwA: 134.00, fB: 0.7, fC: 0.65}, {pre: -1, fwA: 140.00, fB: 0.73, fC: 0.69} ]
			, "GA": [ {pre: [ {min:300,max:303}, {min:305,max:307} ], fwA: 111.00, fB: 0.58, fC: 0.54}, {pre: -1, fwA: 115.00, fB: 0.57, fC: 0.54} ]
			, "IA": [ {pre: 0, fwA: 188.00, fB: 0.98, fC: 0.94} ]
			, "ID": [ {pre: 0, fwA: 419.00, fB: 1.26, fC: 1.19} ]
			, "IL": [ {pre: 0, fwA: 151.00, fB: 0.79, fC: 0.74} ]
			, "IN": [ {pre: 0, fwA: 146.00, fB: 0.76, fC: 0.72} ]
			, "KS": [ {pre: 0, fwA: 193.00, fB: 1.01, fC: 0.95} ]
			, "KY": [ {pre: 0, fwA: 128.00, fB: 0.67, fC: 0.62} ]
			, "LA": [ {pre: 0, fwA: 153.00, fB: 0.8, fC: 0.75} ]
			, "MA": [ {pre: 0, fwA: 146.00, fB: 0.76, fC: 0.73} ]
			, "MD": [ {pre: 0, fwA: 116.00, fB: 0.6, fC: 0.56} ]
			, "ME": [ {pre: [ {min:'039',max:'043'} ], fwA: 157.00, fB: 0.82, fC: 0.78}, {pre: -1, fwA: 165.00, fB: 0.86, fC: 0.83} ]
			, "MI": [ {pre: [ {min:484,max:489}, {min:493,max:495} ], fwA: 157.00, fB: 0.82, fC: 0.78}, {pre: [ {min:496,max:499} ], fwA: 488.00, fB: 0.97, fC: 0.93}, {pre: -1, fwA: 142.00, fB: 0.74, fC: 0.7} ]
			, "MN": [ {pre: 0, fwA: 201.00, fB: 1.05, fC: 1} ]
			, "MO": [ {pre: [ 630, 631, {min:635/*!!!*/,max:639} ], fwA: 172.00, fB: 0.9, fC: 0.85}, {pre: -1, fwA: 176.00, fB: 0.92, fC: 0.87} ]
			, "MS": [ {pre: 0, fwA: 140.00, fB: 0.73, fC: 0.69} ]
			, "MT": [ {pre: 0, fwA: 419.00, fB: 1.26, fC: 1.19} ]
			, "NC": [ {pre: [ 279, {min:287,max:289} ], fwA: 107.00, fB: 0.56, fC: 0.52}, {pre: [ 278, 284, 285 ], fwA: 102.00, fB: 0.53, fC: 0.5}, {pre: -1, fwA: 94.00, fB: 0.49, fC: 0.46} ]
			, "ND": [ {pre: 0, fwA: 441.00, fB: 1.26, fC: 1.19} ]
			, "NE": [ {pre: 0, fwA: 209.00, fB: 1.09, fC: 1.04} ]
			, "NH": [ {pre: 0, fwA: 153.00, fB: 0.8, fC: 0.75} ]
			, "NJ": [ {pre: 0, fwA: 130.00, fB: 0.68, fC: 0.63} ]
			, "NM": [ {pre: [ {min:870,max:875}, 877, 884 ], fwA: 214.00, fB: 1.12, fC: 1.06}, {pre: -1, fwA: 209.00, fB: 1.09, fC: 1.04} ]
			, "NV": [ {pre: 0, fwA: 226.00, fB: 1.18, fC: 1.13} ]
			, "NY": [ {pre: [ {min:100,max:119} ], fwA: 136.00, fB: 0.71, fC: 0.67}, {pre: -1, fwA: 142.00, fB: 0.74, fC: 0.7} ]
			, "OH": [ {pre: 0, fwA: 130.00, fB: 0.68, fC: 0.63} ]
			, "OK": [ {pre: 0, fwA: 184.00, fB: 0.96, fC: 0.92} ]
			, "OR": [ {pre: 0, fwA: 419.00, fB: 1.32, fC: 1.25} ]
			, "PA": [ {pre: [ 157, 158, {min:160,max:165}, {min:167,max:169}, {min:177,max:179}, {min:182,max:188} ], fwA: 132.00, fB: 0.69, fC: 0.64}, {pre: -1, fwA: 128.00, fB: 0.67, fC: 0.62} ]
			, "RI": [ {pre: 0, fwA: 142.00, fB: 0.74, fC: 0.7} ]
			, "SC": [ {pre: [ 293, 296, 297 ], fwA: 109.00, fB: 0.57, fC: 0.53}, {pre: -1, fwA: 111.00, fB: 0.58, fC: 0.54} ]
			, "SD": [ {pre: 0, fwA: 419.00, fB: 1.26, fC: 1.19} ]
			, "TN": [ {pre: [ {min:370,max:374}, 385 ], fwA: 123.00, fB: 0.64, fC: 0.61}, {pre: [ {min:376,max:379} ], fwA: 117.00, fB: 0.61, fC: 0.58}, {pre: -1, fwA: 132.00, fB: 0.69, fC: 0.64} ]
			, "TX": [ {pre: [ {min:797,max:799} ], fwA: 199.00, fB: 1.04, fC: 0.98}, {pre: -1, fwA: 182.00, fB: 0.96, fC: 0.9} ]
			, "UT": [ {pre: 0, fwA: 224.00, fB: 1.17, fC: 1.11} ]
			, "VA": [ {pre: [ {min:230,max:243}, 245 ], fwA: 107.00, fB: 0.56, fC: 0.52}, {pre: -1, fwA: 112.00, fB: 0.58, fC: 0.54} ]
			, "VT": [ {pre: 0, fwA: 155.00, fB: 0.8, fC: 0.76} ]
			, "WA": [ {pre: 0, fwA: 262.00, fB: 1.37, fC: 1.29} ]
			, "WI": [ {pre: [ {min:540,max:545}, 547, 548 ], fwA: 184.00, fB: 0.96, fC: 0.92}, {pre: -1, fwA: 176.00, fB: 0.92, fC: 0.87} ]
			, "WV": [ {pre: 0, fwA: 114.00, fB: 0.59, fC: 0.57} ]
			, "WY": [ {pre: 0, fwA: 419.00, fB: 1.2, fC: 1.15} ]
		}//---	lib.shipping.factors
		,
		/**
		 * Perform the calculations by extracting field data
		 */
		performCalculations : function(){
			if( ! LIB.form.validate('shipping-estimate-form') ) return false;
			
			var state = myDOM('state').attr('value')
				, weight = myDOM('weight').attr('value')
				, zip = myDOM('zip').attr('value')
				, result = this.calc(state, zip, weight)
				;
			
			//format result
			result = '$' + result.toFixed(2);
			
			myDOM('shipping-estimate-result').attr('innerHTML', '<div>Estimated Shipping = <span class="result">' + result + '</span></div>');
			return false;
		}
		,
		/**
		 * Calculate the shipping cost for given params
		 * @param string state shipping state abbreviation
		 * @param string/int shipping zip zipcode
		 * @param number weight decimal value of total shipping weight
		 */
		calc: function(state, zip, weight){
			var factors = LIB.shipping.factors[state]	//get factors for state - narrow down later
				,factor
				,prefix
				, catchAll				//catch-all for factor, used when multiple prefixes provided
				, isFound				//flag to stop checking within loops
				;
			
			LIB.tools.log('looping factors for', state, zip, weight, factors); /* ### */
			for(var f = 0, fStop = factors.length; f < fStop; f++){
				catchAll = undefined;
				factor = factors[f];
				
				LIB.tools.log('checking prefix', isFound, catchAll); /* ### */
				//check if we're given a range or specific value
				if( factor.pre === 0 || factor.pre === - 1){
					//remember the catch-all so we can use it later if necessary
					//but don't stop checking, because the order given doesn't matter
					catchAll = factor;
					LIB.tools.log('saving catchall', isFound, catchAll); /* ### */
				}//--if pre = 0 or -1
				else if( LIB.tools.isArray(factor.pre) ){
					isFound = false;
					for(var p = 0, pStop = factor.pre.length; p < pStop; p++){
						prefix = factor.pre[p];

						LIB.tools.log('looping prefixes', isFound, prefix); /* ### */
						
						//if it's an object, check the min/max
						if( LIB.tools.isObject( prefix ) ){
							if( (prefix.min+'00') <= zip && zip <= (prefix.max+'00') ){
								isFound = true;
								break;
							}
							LIB.tools.log('prefix obj:', prefix, isFound); /* ### */
						}//--check object
						//otherwise just check the number
						else {
							//if given zipcode starts with prefix, stop looking
							if( zip.indexOf(prefix) == 0 ){
								isFound = true;
								LIB.tools.log('prefix found', isFound); /* ### */
								break;
							}
						}//--check number
					}
					
					
				}//--if pre isArray

			}//--loop factors
			
			LIB.tools.log('looping finished', isFound, factor); /* ### */
			
			//if we didn't find anything, use the catchall
			if(!isFound){
				factor = catchAll;
			}
			
			LIB.tools.log('calculating', factor); /* ### */
			
			//now do the calculation with the factors
			//	EQ: (f * W) * (1 + surcharge) + 25
			weight = parseFloat(weight);
			var result = (1 + this.fuel_surcharge);
			if( weight < 201 ){
				result *= (factor.fwA);
			}
			else if( weight < 1000 ){
				result *= (factor.fB * weight);
			}
			else {
				result *= (factor.fC * weight);
			}
			
			result += 25.0;
			return result;
		}//---	lib.shipping.calc
	}///----	lib.shipping
};

//attach sublibraries to manipulation object (to avoid writing an .extend method?)
for(func in LIB){
	myDOM[func] = LIB[func];
}
return myDOM;
})(/*jQuery*/);



function checkForm()
{
	if( document.getElementById('state').value == "" )
	{
		alert( "Please Select a State" );
		document.getElementById('state').focus();
		return;
	}

	if( document.getElementById('weight').value == "" )
	{
		alert( "No weight is available, please call for shipping information." );
		document.getElementById('weight').focus();
		return;
	}


if (document.getElementById('weight').value < 201) {
	  w = document.getElementById('weight').value; 
	  j = document.getElementById('state').value;
      a = strMinArray[j];
	  b = (a);// * 1.13 * 1.15;
	  c = b;// + 40;
	  d = Math.round(c);
	  alert( "Shipping Cost is about $" + (d))  }
	else	
	if (document.getElementById('weight').value > 200) {
	  if (document.getElementById('weight').value <= 1000) {
	    w = document.getElementById('weight').value;
	    j = document.getElementById('state').value;
		a = strOneHArray[j];
	  	b = ((w/100) * a);// * 1.13 * 1.15;
	  	c = b;// + 40;
	  	d = Math.round(c);
	    alert( "Shipping Cost is about $" + (d))  }
	  else
	   if (document.getElementById('weight').value > 1000) {
	     w = document.getElementById('weight').value; 
	     j = document.getElementById('state').value;
		 a = strOneTArray[j];
	  	 b = ((w/100) * a);// * 1.13 * 1.15;
	  	 c = b;// + 40;
	  	 d = Math.round(c);
   	     alert( "Shipping Cost is about $" + (d))  }}
}
